<?php

switch ($messaggio) {

case "Configura e personalizza HotelDruid":	$messaggio = "Конфигурирование и настройка HotelDruid"; break;
case "Scegli la lingua":  			$messaggio = "Выбрать язык"; break;
case "cambia la lingua":  			$messaggio = "выберите язык"; break;
case "Tabella con tutte le prenotazioni":  	$messaggio = "Таблица со всеми бронями"; break;
case "Scegli le colonne da far comparire":  	$messaggio = "Выбрать колонки, которые будут показаны"; break;
case "n° di settimane":  			$messaggio = "n° недель"; break;
case "n° di giorni":  				$messaggio = "n° дней"; break;
case "caparra":  				$messaggio = "депозит"; break;
case "pagato":  				$messaggio = "оплачен"; break;
case "resto da pagare":  			$messaggio = "оставлен для оплаты"; break;
case "n° di persone":  				$messaggio = "n° людей"; break;
case "commento":  				$messaggio = "комментарий"; break;
case "costo aggiuntivo unico":  		$messaggio = "единичная дополнительная издержка"; break;
case "abbreviazione":  				$messaggio = "сокращение"; break;
case "costo aggiuntivo settimanale":  		$messaggio = "еженедельные дополнительные расходы"; break;
case "costo aggiuntivo giornaliero":  		$messaggio = "ежедневные дополнительная издержка"; break;
case "cambia le colonne":  			$messaggio = "изменить колонки"; break;
case "Tabelle dei mesi":  			$messaggio = "Таблица месяцев"; break;
case "Numero di tabelle del 2° tipo":  		$messaggio = "Число таблиц  2-го типа"; break;
case "cambia":  				$messaggio = "изменить"; break;
case "Torna al menù principale":  		$messaggio = "Обратно на главное меню"; break;
case "a":  					$messaggio = "на"; break;
case "La lingua è stata cambiata":  		$messaggio = "Язык изменен"; break;
case "La valuta è stata cambiata":  		$messaggio = "Валюта была изменена"; break;
case "Le colonne sono state cambiate":  	$messaggio = "Колонки были изменены"; break;
case "Il numero di tabelle è stato cambiato":  	$messaggio = "Число таблиц было изменено"; break;
case "Documenti":  				$messaggio = "Документы"; break;
case "documento":  				$messaggio = "документ"; break;
case "cambia i nomi dei documenti":  		$messaggio = "изменить названия документов"; break;
case "I nomi dei documenti sono stati cambiati":	$messaggio = "Названия документов были изменены"; break;
case "Formato di visualizzazione dei soldi":  	$messaggio = "Формат просмотра денег"; break;
case "cambia formato":  			$messaggio = "изменить формат"; break;
case "Il formato di visualizzazione dei soldi è stato cambiato":	$messaggio = "Формат просмотра денег был изменен"; break;
case "Le date sono sbagliate":  		$messaggio = "Даты неверны"; break;
case "Le date dei menù a tendina sono state cambiate":	$messaggio = "Даты в выпадающем меню были изменены"; break;
case "Scegli le date":  			$messaggio = "Выбрать даты"; break;
case "nei menù a tendina":  			$messaggio = "в выпадающем меню"; break;
case "dal":  					$messaggio = "от"; break;
case "al":  					$messaggio = "до"; break;
case "Tronca i cognomi nelle tabelle dopo ":	$messaggio = "Урезать фамилии в таблицах после "; break;
case "caratteri per colonna":  			$messaggio = "буквы на колонках"; break;
case "La lunghezza dei cognomi nelle tabelle dei mesi è stata cambiata":	$messaggio = "Длина фамилий в месячных таблицах была изменена"; break;
case "Cambia il numero delle tariffe":  	$messaggio = "Изменить число тарифов"; break;
case "per l'anno":  				$messaggio = "для года"; break;
case "Il numero delle tariffe è stato cambiato":	$messaggio = "Число цен было изменено"; break;
case "Il numero di tariffe è sbagliato":  	$messaggio = "Число цен неверно"; break;
case "Sistema di backup":  			$messaggio = "Резервное сохранение системы"; break;
case "Il numero delle righe è sbagliato":  	$messaggio = "Число строк неверно"; break;
case "Cambia il numero delle righe":  		$messaggio = "Изменить число строк"; break;
case "Il numero delle righe della tabella con tutte le prenotazioni è stato cambiato":	$messaggio = "Число строк в таблице со всеми бронями было изменено"; break;
case "Il numero delle righe della tabella con la storia delle entrate e delle uscite è stato cambiato":	$messaggio = "Число строк в таблице истории платежей было изменено"; break;
case "Tabella con la storia delle entate e uscite":	$messaggio = "Таблица истории платежей"; break;
case "Il formato di visualizzazione delle date è stato cambiato":	$messaggio = "Формат просмотра дат был изменен"; break;
case "Formato di visualizzazione delle date":	$messaggio = "Формат просмотра дат"; break;
case "Tabella con tutti i clienti":  		$messaggio = "Таблица всех клиентов"; break;
case "Il numero delle righe della tabella con tutti i clienti è stato cambiato":	$messaggio = "Число строк в таблице всех клиентов было изменено"; break;
case "Si deve sceliere qualche dato da inserire nella colonna gruppo":	$messaggio = "Вы должны выбрать некоторые данные для вставки в групповую колонку"; break;
case "Si deve inserire il nome della colonna gruppo":	$messaggio = "Вы должны вставить имена в групповую колонку"; break;
case "La colonna gruppo è stata aggiunta":  	$messaggio = "Групповая колонка была добавлена"; break;
case "Aggiungi una colonna gruppo":  		$messaggio = "Добавить групповую колонку"; break;
case "Aggiungi colonna gruppo":  		$messaggio = "Добавить групповую колонку"; break;
case "chiamata":  				$messaggio = "с именем"; break;
case "con":  					$messaggio = "на"; break;
case "colonna gruppo":  			$messaggio = "групповая колонка"; break;
case "separatore":  				$messaggio = "разделитель"; break;
case "spazio":  				$messaggio = "пробел"; break;
case "trattino":  				$messaggio = "дефис"; break;
case "a capo":  				$messaggio = "новая строка"; break;
case "Pagine per il sito web":  		$messaggio = "Страницы Web-сайта"; break;
case "nome della tariffa":  			$messaggio = "название тарифа"; break;
case "data di inserimento":  			$messaggio = "добавление данных"; break;
case "tariffa completa":  			$messaggio = "полная цена"; break;
case "Gestione utenti":  			$messaggio = "Управление пользователями"; break;
case "Personalizzazioni dell'utente":  		$messaggio = "Настройки пользователей"; break;
case "Cambia":  				$messaggio = "Изменить"; break;
case "quelle di":  				$messaggio = "пользователей категории"; break;
case "Importa i nomi dei documenti":  		$messaggio = "Импортировать имена документов"; break;
case "Importa":  				$messaggio = "Импорт"; break;
case "dell'utente":  				$messaggio = "пользователя"; break;
case "I minuti di durata di sessioni e transazioni sono stati cambiati":	$messaggio = "Продолжительность в минутах сессий и транзакций была изменена"; break;
case "Le ore di anticipo dell'inizio delle prenotazioni sono state cambiate":	$messaggio = "Часы аванса начала брони были изменены"; break;
case "Minuti dopo i quali considerare scadute sessioni e transazioni non aggiornate":	$messaggio = "Время в минутах, после которых считаются истекшими необновленные сессии и транзакции"; break;
case "Numero di ore di cui anticipare il momento in cui si considera iniziata una prenotazione":	$messaggio = "Число часов ожидания момента, после которого брони считаются сделанными"; break;
case "utente":  				$messaggio = "пользователь"; break;
case "Interconnessioni":  			$messaggio = "Взаимосвязи"; break;
case "Assegnazione automatica disattivata":  	$messaggio = "Автоматическое назначение запрещеноно"; break;
case "Assegnazione automatica attivata":  	$messaggio = "Автоматическое назначение разрешено"; break;
case "Attiva":  				$messaggio = "Разрешить"; break;
case "Disattiva":  				$messaggio = "Запретить"; break;
case "Scegli il tema grafico":  		$messaggio = "Выберите графическую тему"; break;
case "Il tema grafico è stato cambiato":  	$messaggio = "Графическая тема была изменена"; break;
case "Registrazione degli orari di entrata ed uscita attivata":	$messaggio = "Регистрация вписок и выписок разрешена"; break;
case "Registrazione degli orari di entrata ed uscita disattivata":	$messaggio = "Регистрация вписок и выписок запрещена"; break;
case "Le ore di differenza con l'orario del server sono state cambiate":	$messaggio = "Часы разницы с серверным временем были изменены"; break;
case "Ore di differenza con l'orario del server": 	$messaggio = "Часы разницы с серверным временем"; break;
case "ora attuale":  				$messaggio = "текущий час"; break;
case "numero":  				$messaggio = "число"; break;
case "cognome cliente":  			$messaggio = "фамилия клиента"; break;
case "data iniziale":  				$messaggio = "дата начала"; break;
case "data finale":  				$messaggio = "дата окончания"; break;
case "Le colonne necessarie sono state cambiate":	$messaggio = "Нужные колонки были изменены"; break;
case "Non mostrare prenotazioni che non hanno almeno una di queste colonne necessarie (non selezionarene per mostrare tutte)":	$messaggio = "Не показывать брони, которые не имеют как минимум одной из данных необходимых колонок (не выбирайте ничего, чтобы показать все)"; break;
case "cambia le colonne necessarie":  		$messaggio = "измените нужные колонки"; break;
case "Metodo di pagamento eliminato":  		$messaggio = "Метод оплаты удален"; break;
case "Nuovo metodo di pagamento aggiunto":  	$messaggio = "Новый метод оплаты добавлен"; break;
case "Metodi di pagamento":  			$messaggio = "Методы оплаты"; break;
case "elimina":  				$messaggio = "удалить"; break;
case "aggiungi":  				$messaggio = "добавить"; break;
case "Quadro indicativo disponibilità":  	$messaggio = "Показать краткий обзор доступных номеров"; break;
case "non mostrare":  				$messaggio = "не показывать"; break;
case "Il modo di visualizzazione del quadro di disponibilità è stato cambiato":	$messaggio = "Режим отображения таблицы доступности изменён"; break;
case "Controllo disponibilità":  		$messaggio = "Проверка доступных номеров"; break;
case "settimane di intervallo":  		$messaggio = "недели интервала"; break;
case "giorni di intervallo":  			$messaggio = "дни интервала"; break;
case "Giorno di inizio/fine settimana cambiato":	$messaggio = "День начала/конца недели изменен"; break;
case "Giorno di inizio/fine settimana nelle tabelle":	$messaggio = "День начала/конца недели в таблицах"; break;
case "Anno":  					$messaggio = "Год"; break;
case "Creazione automatica del nuovo anno disattivata (importando i dati dall'anno precedente al primo login di un utente)":	$messaggio = "Автоматическое создание нового  года запрещено (импортирование данных из предыдущего года в первый вход любого пользователя)"; break;
case "Creazione automatica del nuovo anno attivata (importando i dati dall'anno precedente al primo login di un utente)":	$messaggio = "Автоматическое создание нового  года разрешено (импортирование данных из предыдущего года в первый вход любого пользователя)"; break;
case "Creazione automatica nuovo anno disattivata":	$messaggio = "Автоматическое создание нового  года запрещено"; break;
case "Creazione automatica nuovo anno attivata":	$messaggio = "Автоматическое создание нового  года разрешено"; break;
case "Sostituisci la parola":  			$messaggio = "Заменить слово"; break;
case "Parole da sostituire":  			$messaggio = "Слова для замены"; break;
case "La parola da sostituire è stata aggiunta":	$messaggio = "Слово для замены было добавлено"; break;
case "La parola da sostituire è stata eliminata":	$messaggio = "Слово для замены было удалено"; break;
case "modifica il documento":  			$messaggio = "изменить документ"; break;
case "Aggiungi ai documenti":  			$messaggio = "Добавить документы"; break;
case "variabili personalizzate":  		$messaggio = "обычные переменные"; break;
case "Cambia il numero dei documenti":  	$messaggio = "Изменить число документов"; break;
case "Il numero di documenti è stato cambiato":	$messaggio = "Число документов изменено"; break;
case "Il numero di documenti è sbagliato":  	$messaggio = "Неправильное число документов"; break;
case "Indirizzo email":  			$messaggio = "Адрес e-mail"; break;
case "Mascherare la provenienza delle email sull'envelope":	$messaggio = "Скрыть отправителя e-mail"; break;
case "Il mascheramento della provenienza delle email è stato cambiato":	$messaggio = "Параметры скрытия отправителя e-mail были изменены"; break;
case "SI":  					$messaggio = "ДА"; break;
case "NO":  					$messaggio = "НЕТ"; break;
case "Cartelle in cui creare le pagine per il sito web":	$messaggio = "Папки, в которых создаются страницы сайта"; break;
case "alla cartella di HotelDruid, se non iniziano con /":	$messaggio = "HotelDruid, если начинается не с /"; break;
case "Non ho i permessi di scrittura sulla cartella":	$messaggio = "Не разрешена запись в папку"; break;
case "La cartella inserita <div style=\"display: inline; color: red;\">non esiste</div>":	$messaggio = "Указанная папка <div style=\"display: inline; color: red;\">не существует</div>"; break;
case "Le cartelle dove vengono create le pagine per il sito web sono state cambiate":	$messaggio = "Папка для создания страниц сайта изменена"; break;
case "Selezionare in modo predefinito":  	$messaggio = "С выбором по умолчанию"; break;
case "tutte le prenotazioni":  			$messaggio = "все брони"; break;
case "prenotazioni del periodo corrente":  	$messaggio = "текущий период броней"; break;
case "La selezione predefinita delle prenotazioni nella tabella con tutte le prenotazioni è stata cambiata":	$messaggio = "Выбор по умолчанию броней в таблице всех броней был изменен"; break;
case "Numero di righe dopo cui ripetere la riga delle date":	$messaggio = "Число строк, после которых показывать снова строку дат"; break;
case "Il numero  di righe dopo cui ripetere la riga delle date è stato cambiato":	$messaggio = "Число строк, после которых показывать снова строку дат, было изменено"; break;
case "orario entrata stimato":  		$messaggio = "примерно время регистрации"; break;
case "Mostrare i giorni nella riga delle date?":	$messaggio = "Показать дни в строке дат?"; break;
case "I giorni da mostrare nella tabella dei mesi sono stati cambiati":	$messaggio = "Дни для показа в строке дат были изменены"; break;
case "Nazioni":  				$messaggio = "Страны"; break;
case "Elimina tutte":  				$messaggio = "Удалить все"; break;
case "Ripristina predefinite":  		$messaggio = "Восстановить умолчания"; break;
case "Importa le nazioni":  			$messaggio = "Импорт стран"; break;
case "Regioni/provincie":  			$messaggio = "Регионы"; break;
case "Importa le regioni/provincie":  		$messaggio = "Импорт регионов"; break;
case "Nazione cancellata":  			$messaggio = "Страна удалена"; break;
case "Regione/provincia cancellata":  		$messaggio = "Регион удален"; break;
case "Nuova nazione aggiunta":  		$messaggio = "Новая страна добавлена"; break;
case "Nazioni predefinite ripristinate":  	$messaggio = "Страны по умолчанию восстановлены"; break;
case "Nazioni cancellate":  			$messaggio = "Страны удалены"; break;
case "Nazioni importate":  			$messaggio = "Страны импортированы"; break;
case "Nuova regione/provincia aggiunta":  	$messaggio = "Новый регион добавлен"; break;
case "Regioni/provincie predefinite ripristinate":	$messaggio = "Регионы по умолчанию восстановлены"; break;
case "Regioni/provincie cancellate":  		$messaggio = "Регионы удалены"; break;
case "Regioni/provincie importate":  		$messaggio = "Регионы импортированы"; break;
case "Parentele":  				$messaggio = "Отношения родства"; break;
case "Importa le parentele":  			$messaggio = "Импорт отношений родства"; break;
case "Parentela cancellata":  			$messaggio = "Отношение родства удалено"; break;
case "Nuova parentela aggiunta":  		$messaggio = "Новое отношение родства добавлено"; break;
case "Parentele predefinite ripristinate":  	$messaggio = "Отношения родства по умолчанию восстановлены"; break;
case "Parentele cancellate":  			$messaggio = "Отношения родства удалены"; break;
case "Parentele importate":  			$messaggio = "Отношения родства импортированы"; break;
case "origine":  				$messaggio = "источник"; break;
case "Origini delle prenotazioni":  		$messaggio = "Источники броней"; break;
case "Nuova origine delle prenotazioni aggiunta":	$messaggio = "Новые источники броней добавлены"; break;
case "Origine delle prenotazioni eliminata":  	$messaggio = "Источник броней удален"; break;
case "Nome combinazione":  			$messaggio = "Имя комбинации"; break;
case "prenotazioni correnti e future":  	$messaggio = "текущие и будущие брони"; break;
case "Personalizzazioni di <b>tutti gli utenti</b>":  	$messaggio = "Настройки <b>всех пользователей</b>"; break;
case "tutti gli utenti":  			$messaggio = "все пользователи"; break;
case "Personalizzazioni del gruppo":  		$messaggio = "Настройки для группы"; break;
case "gruppo":  				$messaggio = "группа"; break;
case "Log delle query di modifica generate":	$messaggio = "Регистрация в журнале поступивших запросов на изменение"; break;
case "da tutti gli utenti":  			$messaggio = "от всех пользователей"; break;
case "dall'utente":  				$messaggio = "от пользователя"; break;
case "dal gruppo":  				$messaggio = "от группы"; break;
case "attivato":				$messaggio = "разрешена"; break;
case "disattivato":				$messaggio = "запрещена"; break;
case "Vedi i log":  				$messaggio = "Посмотреть журнал"; break;
case "Log delle query di modifica effettuate dagli utenti negli ultimi":	$messaggio = "Журнал запросов на изменение поступивших от пользователей за последние"; break;
case "giorni":  				$messaggio = "дни"; break;
case "Utente":  				$messaggio = "Пользователь"; break;
case "Data":  					$messaggio = "Дата"; break;
case "Query":  					$messaggio = "Запрос"; break;
case "Cancella tutti i log":  			$messaggio = "Удалить все журналы"; break;
case "Log delle query di modifica degli utenti normali disattivato":	$messaggio = "Регистрация в журнале запросов на изменение, поступивших от обычных пользователей, отключена"; break;
case "Log delle query di modifica degli utenti normali attivato":	$messaggio = "Регистрация в журнале запросов на изменение, поступивших от обычных пользователей, включена"; break;
case "Allineare la disponibilità con la data di arrivo?":	$messaggio = "Упорядочить наличие по дате прибытия?"; break;
case "L'allineamento dei giorni con la disponibilità nella tabella dei mesi è stato cambiato":	$messaggio = "Упорядочение дней по наличию в месячных таблицах изменено"; break;
case "Torna indietro":  			$messaggio = "Назад"; break;
case "Allineare la disponibilità con le date di arrivo potrebbe generare confusione ed errori sulle date di partenza, si è sicuri di voler continuare?":	$messaggio = "Упорядочение наличия по датам прибытия пожет вызвать путаницу и ошибки в дни отбытия. Вы действительно хотите продолжить?"; break;
case "Documenti di identità":  			$messaggio = "Документ, удостоверяющий личность"; break;
case "Tipo di documento di identità eliminato":	$messaggio = "Тип документа, удостоверяющего личность"; break;
case "Nuovo tipo di documento di identità aggiunto":	$messaggio = "Новый тип документа удостоверяющего личность добавлен"; break;
case "Tipi di documento di identità predefiniti ripristinati":	$messaggio = "Выбираемые по умолчанию типы документа удостоверяющего личность восстановлены"; break;
case "Tipi di documento di identità cancellati":	$messaggio = "Типы документа удостоверяющего личность удалены"; break;
case "Tipi di documento di identità importati":	$messaggio = "Типы документа удостоверяющего личность импортированы"; break;
case "Importa i documenti di identità":  	$messaggio = "Импортировать документы удостоверяющие личность "; break;
case "codice":  				$messaggio = "Код"; break;
case "Nuova nazione":  				$messaggio = "Новая страна"; break;
case "Nuova regione/provincia":  		$messaggio = "Новый регион"; break;
case "Nuovo documento d'identità":  		$messaggio = "Новый документ, удостоверяющий личность"; break;
case "Nuova parentela":  			$messaggio = "Новое отношение родства"; break;
case "Elimina tutti":  				$messaggio = "Удалить все"; break;
case "Ripristina predefiniti":  		$messaggio = "Восстановить умолчания"; break;
case "Città":  					$messaggio = "Города"; break;
case "Nuova città":  				$messaggio = "Новый город"; break;
case "Importa le città":  			$messaggio = "Импортировать города"; break;
case "Città cancellata":  			$messaggio = "Город удалён"; break;
case "Nuova città aggiunta":  			$messaggio = "Новый город добавлен"; break;
case "Città predefinite ripristinate":  	$messaggio = "Восстановлены города по умолчанию"; break;
case "Città cancellate":  			$messaggio = "Города удалены"; break;
case "Città importate":  			$messaggio = "Города импортированы"; break;
case "nella regione/provincia di":  		$messaggio = "в регионе"; break;
case "nella nazione":  				$messaggio = "в стране"; break;
case "Titoli dei clienti":  			$messaggio = "Обращение к клиенту"; break;
case "sesso":  					$messaggio = "пол"; break;
case "m":  					$messaggio = "м"; break;
case "f":  					$messaggio = "ж"; break;
case "Titolo dei clienti eliminato":  		$messaggio = "Обращение к клиенту удалено"; break;
case "Nuovo titolo dei clienti aggiunto":  	$messaggio = "Новое обращение к клиенту добавлено"; break;
case "I dati della struttura sono stati cambiati":	$messaggio = "Структурные данные были изменены"; break;
case "Dati della struttura":  			$messaggio = "Структурные данные"; break; # Реквизиты (?) case "Nome":  					$messaggio = "Имя"; break;
case "Nome":  					$messaggio = "Имя"; break;
case "Tipo":  					$messaggio = "Тип"; break;
case "Numero stelle":  				$messaggio = "Число звёзд"; break;
case "Nazione":  				$messaggio = "Страна"; break;
case "Comune":  				$messaggio = "Город"; break;
case "Indirizzo":  				$messaggio = "Адрес"; break;
case "CAP":  					$messaggio = "Почтовый индекс"; break;
case "Telefono":  				$messaggio = "Телефон"; break;
case "Fax":  					$messaggio = "Факс"; break;
case "Codice fiscale":  			$messaggio = "ИНН"; break;
case "Partita iva":  				$messaggio = "Счёт НДС"; break;
case "Modifica i dati della struttura":  	$messaggio = "Изменить структурные данные"; break;
case "Clicca su un documento per modificarlo":	$messaggio = "Щёлкните на документе, чтобы изменить его"; break;
case "Cambia l'ordine dei documenti":  		$messaggio = "Изменить порядок документов"; break;
case "Applica i cambiamenti":  			$messaggio = "Применить изменения"; break;
case "Documento":  				$messaggio = "Документ"; break;
case "ex":  					$messaggio = "ex"; break;
case "L'ordine dei documenti è stato cambiato":	$messaggio = "Порядок документов изменён"; break;
case "l'ordine delle tariffe è stato cambiato":	$messaggio = "порядок тарифов изменён"; break;
case "cambia l'ordine delle tariffe":  		$messaggio = "Изменить порядок тарифов"; break;
case "tariffa":  				$messaggio = "тариф"; break;
case "valore predefinito a cui arrotondare le percentuali dei prezzi":	$messaggio = "пороговая величина округления процентов цен"; break;
case "il":  					$messaggio = ""; break;
case "è stato cambiato":  			$messaggio = "изменена"; break;
case "password per la visualizzazione dei dati delle carte di credito":	$messaggio = "пароль для просмотра данных кредитных карт"; break;
case "attivata":  				$messaggio = "разрешено"; break;
case "disattivata":  				$messaggio = "запрещено"; break;
case "cambia la password":  			$messaggio = "сменить пароль"; break;
case "<b>Attenzione</b>: se si perde questa password non sarà più possibile leggere i dati delle carte di credito inserite":	$messaggio = "<b>Внимание!</b> если Вы потеряете этот пароль, Вы больше не сможете прочитать сохранённые данные о кредитных картах"; break;
case "nuova password":  			$messaggio = "новый пароль"; break;
case "ripetere password":  			$messaggio = "повторите пароль"; break;
case "attiva la password":  			$messaggio = "активировать пароль"; break;
case "le password inserite non coincidono":  	$messaggio = "введённые пароли не совпадают"; break;
case "errore nelle funzioni ssl":  		$messaggio = "ошибка в функции ssl"; break;
case "<b class=\"colred\">Attenzione</b>: tutti i dati delle carte di credito verranno cancellati":	$messaggio = "<b class=\"colred\">Внимание!</b> все данныые о кредитных картах будут удалены"; break;
case "continua":  				$messaggio = "продолжить"; break;
case "vecchia password":  			$messaggio = "старый пароль"; break;
case "cambiata":  				$messaggio = "изменён"; break;
case "piano":  					$messaggio = "этаж"; break;
case "casa":  					$messaggio = "строение"; break;
case "2°":  					$messaggio = "2й"; break;
case "3°":  					$messaggio = "3й"; break;
case "2° codice":  				$messaggio = "2й код"; break;
case "3° codice":  				$messaggio = "3й код"; break;
case "Tabella con i documenti salvati":  	$messaggio = "Таблица с сохранёнными документами"; break;
case "Il numero delle righe della tabella con i documenti salvati è stato cambiato":	$messaggio = "Число строк в таблице сохранённых документов изменено"; break;
case "commissioni":  				$messaggio = "комиссии"; break;
case "resto commissioni":  			$messaggio = "остаток комиссий"; break;
case "documenti salvati":  			$messaggio = "сохранённые документы"; break;
case "Scegli le righe aggiuntive da mostrare":	$messaggio = "Выбрать дополнительные строки для отображения"; break;
case "tasse":  					$messaggio = "Налоги"; break;
case "trasferito in cassa":  			$messaggio = "переведено в кассу"; break;
case "cambia le righe":  			$messaggio = "изменить строки"; break;
case "Le righe aggiuntive sono state cambiate":	$messaggio = "Добавлены дополнительные строки"; break;
case "totale":  				$messaggio = "итого"; break;
case "soldi prenotazioni cancellate":  		$messaggio = "деньги удалённых броней"; break;
case "cognome ospite se differente":  		$messaggio = "фамилия гостя, если отличается"; break;
case "Ragione sociale":  			$messaggio = "Название организации"; break;
case "URL del logo":  				$messaggio = "Web-адрес (URL) логотипа"; break;
case "Nome delle unità da affittare":  		$messaggio = "Название сдаваемых объектов"; break;
case "nome personalizzato":  			$messaggio = "своё название"; break;
case "singolare":  				$messaggio = "единств. число"; break;
case "plurale":  				$messaggio = "множеств. число"; break;
case "genere":  				$messaggio = "род"; break;
case "m":  					$messaggio = "м"; break;
case "f":  					$messaggio = "ж"; break;
case "Il nome delle unità da affittare è stato cambiato":	$messaggio = "Название сдаваемых объектов изменено"; break;
case "Tabelle con le casse":  			$messaggio = "Таблицы кассы"; break;
case "Il numero delle righe delle tabelle con le casse è stato cambiato":	$messaggio = "Число строк таблиц кассы изменено"; break;
case "Elimina il documento":  			$messaggio = "Удалить документ"; break;
case "Sei sicuro di voler eliminare il documento":	$messaggio = "Вы действительно хотите удалить документ"; break;
case "Il documento è stato eliminato":	$messaggio = "Документ удалён"; break;
case "Campi da considerare per la ricerca dei clienti":	$messaggio = "Параметры, учитываемые при поиске клиентов"; break;
case "cognome":  				$messaggio = "фамилия"; break;
case "nome":  					$messaggio = "имя"; break;
case "telefono":  				$messaggio = "тел."; break;
case "città":  					$messaggio = "город"; break;
case "indirizzo":  				$messaggio = "адрес"; break;
case "codice postale":  			$messaggio = "почтовый индекс"; break;
case "I campi da considerare per la ricerca dei clienti sono stati cambiati":	$messaggio = "Параметры, учитываемые при поиске клиентов, изменены"; break;
case "Nome delle unità singole":  		$messaggio = "Название индивидуальных объектов"; break;
case "Tabella dei messaggi":  			$messaggio = "Табло сообщений"; break;
case "Il numero di righe della tabella dei messaggi è stato cambiato":	$messaggio = "Число строк в табло сообщений	изменено"; break;
case "Scarica le email di richiesta disponibiltà dal server di posta":	$messaggio = "Загружать сообщения e-mail с почтового сервера для запросов о наличии мест"; break; # case "per es.":  				$messaggio = "напр."; break;
case "per es.":  				$messaggio = "напр."; break;
case "Protocollo":  				$messaggio = "Протокол"; break;
case "Porta":  					$messaggio = "Порт"; break;
case "default":  				$messaggio = "по умолчанию"; break;
case "persoalizzata":  				$messaggio = "осбственный"; break;
case "Nome utente":  				$messaggio = "Имя пользователя"; break;
case "Password":  				$messaggio = "Пароль"; break;
case "lasciare vuota per chiedere ogni volta":	$messaggio = "оставьте пустым, чтобы запрашивать каждый раз"; break;
case "Identificazione messaggi di richiesta":	$messaggio = "Идентификация сообщений с запросом"; break;
case "Messaggio iniziale":  			$messaggio = "Первое сообщение"; break;
case "Qualsiasi messaggio":  			$messaggio = "Любое сообщение"; break;
case "da":  					$messaggio = "от"; break;
case "con oggetto contenete":  			$messaggio = "с темой, содержащей"; break;
case "I dati per lo scaricamento delle email sono sbagliati o incompleti":	$messaggio = "Данные для загрузки сообщений неверны или недостаточны"; break;
case "Lo scaricamento delle email di richiesta disponibiltà dal server di posta è stato cambiato":	$messaggio = "Загрузка сообщений e-mail с почтового сервера для запросов о наличии мест изменена"; break;
case "Colori delle prenotazioni":  		$messaggio = "Цвета броней"; break;
case "Tutto pagato":  				$messaggio = "Всё оплачено"; break;
case "Caparra pagata":  			$messaggio = "Выплачен задаток"; break;
case "Confermate":  				$messaggio = "Подтверждено"; break;
case "Non confermate":  			$messaggio = "Не подтверждено"; break;
case "I colori sono sbagliati":  		$messaggio = "Цвета неправильные"; break;
case "I colori delle prenotazioni sono stati cambiati":	$messaggio = "Цвета броней изменены"; break;
case "Campi personalizzati dei clienti":  	$messaggio = "Характеристики клиентов, задаваемые пользователем"; break;
case "Nuovo campo personalizzato dei clienti aggiunto":	$messaggio = "Новые характеристики клиентов, задаваемые пользователем, добавлены"; break;
case "Campo personalizzato dei clienti eliminato":	$messaggio = "Характеристика клиентов, задаваемая пользователем, удалена"; break;
case "tipo":  					$messaggio = "тип"; break;
case "booleano":  				$messaggio = "булево"; break;
case "testo":  					$messaggio = "текст"; break;
case "Il campo personalizzato contiene caratteri non consentiti":	$messaggio = "Характеристика клиентов, задаваемая пользователем, содержит недопустимые символы"; break;
case "Personalizza":  				$messaggio = "Customize"; break;
case "Nome della valuta principale":  		$messaggio = "Name of the main currency"; break;
case "Regione/provincia":  			$messaggio = "Region"; break;
case "Sito web":  				$messaggio = "Website"; break;
case "Nome contatto":  				$messaggio = "Contact name"; break;
case "valore a cui arrotondare le percentuali delle tasse e delle valute":	$messaggio = "rounding value for percentages of taxes and currencies"; break;
case "email":  					$messaggio = "email"; break;
case "Gestire anche i codici CVC delle carte di credito":	$messaggio = "Manage the CVC codes from credit cards too"; break;
case "Esonero di responsabilità":  		$messaggio = "Disclaimer"; break;
case "la gestione dei codici CVC avverrà sotto la propria responsabilità, essendo a conoscenza che gli standard di sicurezza PCI ne vietano la registrazione":	$messaggio = "the CVC codes will be managed under your own responsibility, being aware that PCI security standards forbid their storage"; break;
case "L'accettazione di questa clausola conferma che gli sviluppatori di questo software sono liberi da ogni responsibilità sulla sicurezza di questi dati":	$messaggio = "Accepting this clause confirms that the developers of this software are free from all responsibilities regarding the security of these data"; break;
case "Accetto":  				$messaggio = "I Accept"; break;
case "Declino":  				$messaggio = "I Decline"; break;
case "La gestione dei codici cvc è stata cambiata":	$messaggio = "The management of CVC codes has been changed"; break;
case "Scegli le righe con i totali da mostrare":	$messaggio = "Choose which totals to show in rows"; break;
case "giornaliero":  				$messaggio = "daily"; break;
case "mensile":  				$messaggio = "montly"; break;
case "tabella":  				$messaggio = "table"; break;
case "Le righe da mostrare nelle tabelle delle casse sono state cambiate":	$messaggio = "Rows shown in cashobxes tables have been changed"; break;
case "partenze e prenotazioni correnti":  	$messaggio = "departures and current reservations"; break;
case "Commenti personalizzati delle prenotazioni":	$messaggio = "Custom comments for reservations"; break;
case "Commento personalizzato della prenotazione eliminato":	$messaggio = "Custom comment for reservation deleted"; break;
case "Nuovo commento personalizzato della prenotazione aggiunto":	$messaggio = "New custom comment for reservation added"; break;
case "Punto vendita ed inventario":  		$messaggio = "Point of sale and inventory"; break;
case "Ordinamento nell'inventario e punto vendita":	$messaggio = "Sorting in inventory and point of sale"; break;
case "alfabetico":  				$messaggio = "alphabetically"; break;
case "per ordine di inserimento":  		$messaggio = "by insertion order"; break;
case "Tasti per operazioni nel punto vendita":	$messaggio = "Buttons for operations in point of sale"; break;
case "L'ordinamento nell'inventario e nel punto vendita è stato cambiato":	$messaggio = "Sorting in inventory and point of sale has been changed"; break;
case "I tasti per operazioni nel punto vendita sono stati cambiati":	$messaggio = "Buttons for operations in point of sale have been changed"; break;
case "Attenzione":  				$messaggio = "Warning"; break;
case "i link per l'esportazione dei calendari in formato ical sono cambiati, ricordarsi di aggiornarli sui calendari esterni":	$messaggio = "the links to export calendars in ical format have changed, remember to update them on external calendars"; break;
case "La tariffa":  				$messaggio = "Rate"; break;
case "è ancora in uso nelle interconnessioni":	$messaggio = "is still in use in interconnections"; break;
case "almeno 8 caratteri, con lettere e numeri o simboli":	$messaggio = "at least 8 characters, with letters and numbers or symbols"; break;
case "diversa dalle ultime":  			$messaggio = "different from last"; break;
case "Condizioni Generali di Contratto":  	$messaggio = "General Terms and Conditions"; break;
case "del servizio di memorizzazione delle carte di credito":	$messaggio = "of the credit cards storage service"; break;
case "La password non è stata modificata":  	$messaggio = "The password has not been modified"; break;
case "password errata":  			$messaggio = "wrong password"; break;
case "adulto":  				$messaggio = "adult"; break;
case "adulti":  				$messaggio = "adults"; break;
case "bambino":  				$messaggio = "child"; break;
case "bambini":  				$messaggio = "children"; break;
case "Numero di tipologie di persone":  	$messaggio = "Number of people types"; break;
case "Tipologia":  				$messaggio = "Type"; break;
case "Può essere ospite principale":  		$messaggio = "Can be main guest"; break;
case "Prezzo in percentuale del prezzo per persona":	$messaggio = "Price in percentage of per person price"; break;
case "arrotondato a":  				$messaggio = "rounded to"; break;
case "Modifica le tipologie di persone":  	$messaggio = "Modify people types"; break;
case "Il numero di tipologie di persone è sbagliato":	$messaggio = "The number of people types is wrong"; break;
case "Il numero di tipologie di persone è stato cambiato":	$messaggio = "The number of people types has been changed"; break;
case "I dati inseriti non sono corretti":  	$messaggio = "Inserted data are incorrect"; break;
case "Le tipologie di persone sono state modificate":	$messaggio = "The people types have been modified"; break;
case "Cambia per tutti gli utenti":  		$messaggio = "Change for all users"; break;
case "Modifica le tipologie di persone per tutti gli utenti":	$messaggio = "Modify people types for all users"; break;
case "tipi di persona":  			$messaggio = "person types"; break;
case "Valuta secondaria chiamata":  		$messaggio = "Secundary currency called"; break;
case "nuova valuta":  				$messaggio = "new currency"; break;
case "con arrotondamento":  			$messaggio = "with rounding"; break;
case "Aggiungi per tutti gli utenti":  		$messaggio = "Add for all users"; break;
case "Elimina la valuta":  			$messaggio = "Delete the currency"; break;
case "Elimina":  				$messaggio = "Delete"; break;
case "Elimina per tutti gli utenti":  		$messaggio = "Delete for all users"; break;
case "La nuova valuta secondaria è stata aggiunta":	$messaggio = "The new secundary currency has been addded"; break;
case "La valuta secondaria":  			$messaggio = "The secundary currency"; break;
case "è stata modificata":  			$messaggio = "has been modified"; break;
case "è stata eliminata":  			$messaggio = "has been deleted"; break;
case "La cartella":  				$messaggio = "The directory"; break;
case "è un duplicato":  			$messaggio = "is a duplicate"; break;
case "le seguenti pagine web verranno cancellate":	$messaggio = "the following web pages will be deleted"; break;
case "le tipologie di persone rimosse erano presenti in alcuni costi aggiuntivi, questi costi vanno aggiornati manualmente se necessario":	$messaggio = "removed person types were present in some extra costs, eventually these costs must be updated manually"; break;
case "Utilizzo dei cookies per la gestione delle sessioni attivato":	$messaggio = "Use of cookies for session handling enabled"; break;
case "Utilizzo dei cookies per la gestione delle sessioni disattivato":	$messaggio = "Use of cookies for session handling disabled"; break;
case "Percorso al file autoload.php di phpmailer":	$messaggio = "Path to autoload.php file for phpmailer"; break;
case "per inviare email attraverso un server remoto":	$messaggio = "to send emails through a remote server"; break;
case "Per inviare le email usare":  		$messaggio = "To send emails use"; break;
case "il server locale":  			$messaggio = "the local server"; break;
case "un server remoto":  			$messaggio = "a remote server"; break;
case "Server di posta SMTP":  			$messaggio = "SMTP mail server"; break;
case "Sicurezza connessione":  			$messaggio = "Connection security"; break;
case "nessuna":  				$messaggio = "no one"; break;
case "Il percorso al file autoload.php di phpmailer è stato cambiato":	$messaggio = "The path to autoload.php file for phpmailer has been changed"; break;
case "Il file inserito <span class=\"colred\">non carica phpmailer</span> correttamente":	$messaggio = "The inserted file <span class=\"colred\">does not load phpmailer</span> correctly"; break;
case "Il metodo per inviare le email è stato cambiato":	$messaggio = "The method to send emails has been changed"; break;
case "Connessione fallita":  			$messaggio = "Falied connection"; break;
case "EHLO fallito":  				$messaggio = "Failed EHLO"; break;
case "Connessione cifrata STARTTLS fallita":  	$messaggio = "STARTTLS encrypted connection failed"; break;
case "EHLO dopo STARTTLS fallito":  		$messaggio = "EHLO after STARTTLS failed"; break;
case "Autenticazione fallita":  		$messaggio = "Failed authentication"; break;
case "I dati per il collegamento al server SMTP sono <span class=\"colred\">sbagliati o incompleti</span>":	$messaggio = "The data to connect to the SMTP server are <span class=\"colred\">wrong or incomplete</span>"; break;
case "I dati per il collegamento al server SMTP sono stati aggiornati":	$messaggio = "The data to connect to the SMTP server have been updated"; break;
case "controllando SPF":  			$messaggio = "checking SPF"; break;
case "Attualmente SPF è configurato correttamente sul dominio della email della struttura":	$messaggio = "Currently SPF is correctly configured on the domain of the property email"; break;
case "Attualmente <span class=\"colred\">SPF non è configurato correttamente</span> sul dominio della email della struttura":	$messaggio = "Currently <span class=\"colred\">SPF is not configured correctly</span> on the domain of the property email"; break;
case "Il mascheramento delle email verrà attivato solo se nel DNS del dominio dell'email del mittente c'è un record TXT per SPF contenente":	$messaggio = "Email masquerading will be activated only if in the DNS of the domain of the sender's email there is a TXT record for SPF containing"; break;
case "Il dominio":  				$messaggio = "The domain"; break;
case "non ha nessun record per SPF":  		$messaggio = "has no record for SPF"; break;
case "nella gestione del suo DNS va aggiunto un record TXT contenente un testo come questo":	$messaggio = "in the management of your DNS you must add a TXT record containing a text like this"; break;
case "Questo è il record SPF attuale del dominio":	$messaggio = "This is the current SPF record of the domain"; break;
case "questo record TXT va modificato nella gestione del DNS del dominio":	$messaggio = "this TXT record must be modified in the management of DNS of the domain"; break;
case "sostituendolo con un testo come questo":	$messaggio = "replacing it with a text like this"; break;
case "Dopo la modifica potrebbero volerci alcune ore affinchè l'aggiornamento sia attivo":	$messaggio = "After the change it may take a few hours for the update to take effect"; break;
case "Formato di nomi e cognomi":  		$messaggio = "Format of names and surnames"; break;
case "non modificare il formato inserito":  	$messaggio = "don't modify inserted format"; break;
case "prima lettera maiuscola, altre lettere minuscole":	$messaggio = "first letter uppercase, other letters lowercase"; break;
case "prima lettera maiuscola, non modificare altre lettere":	$messaggio = "first letter uppercase, do not change other letters"; break;
case "tutte lettere maiuscole":  		$messaggio = "all letters uppercase"; break;
case "tutte lettere minuscole":  		$messaggio = "all letters lowercase"; break;
case "Il formato di inserimento dei nomi e cognimi è stato cambiato":	$messaggio = "The format for inserting names and surnames has been changed"; break;
case "Per il proprio indirizzo email si sta usando un provider pubblico":	$messaggio = "For your email address you are using a public provider"; break;
case "si consiglia quindi di":  		$messaggio = "it is therefore advisable to"; break;
case "configurare il loro server remoto smtp":	$messaggio = "configure their remote smtp server"; break;
case "per inviare email":  			$messaggio = "to avoid that emails sent"; break;
case "da hoteldruid":  				$messaggio = "from hoteldruid"; break;
case "senza che vengano considerate come spam":	$messaggio = "are considered as spam"; break;
case "percorsi relativi":  			$messaggio = "paths relative"; break;
case "Secondo cognome disattivato":  		$messaggio = "Second surname disabled"; break;
case "Secondo cognome attivato":  		$messaggio = "Second surname enabled"; break;
case "Fuso orario":  				$messaggio = "Time zone"; break;
case "nessun fuso orario":  			$messaggio = "no time zone"; break;
case "Si possono creare solo cartelle con nome composto da lettere e numeri":	$messaggio = "Only folders with names that contain letters and numbers can be created"; break;
case "la seguente cartella verrà creata":  	$messaggio = "the following folder will be created"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
